diff avcodec.h @ 376:ba9c3b8088c0 libavcodec

- pict_type exported to AVCodecContext - Added real_pict_num to AVCodecContext, it represent the number of the previous encoded frame, usefull when coding with B frames. - Warning fix in motion_est.c
author pulento
date Sat, 11 May 2002 23:42:16 +0000
parents 8187bb132d85
children 0d73175fbded
line wrap: on
line diff
--- a/avcodec.h	Thu May 09 05:42:27 2002 +0000
+++ b/avcodec.h	Sat May 11 23:42:16 2002 +0000
@@ -5,8 +5,8 @@
 
 #define LIBAVCODEC_VERSION_INT 0x000406
 #define LIBAVCODEC_VERSION     "0.4.6"
-#define LIBAVCODEC_BUILD       4605
-#define LIBAVCODEC_BUILD_STR   "4605"
+#define LIBAVCODEC_BUILD       4606
+#define LIBAVCODEC_BUILD_STR   "4606"
 
 enum CodecID {
     CODEC_ID_NONE, 
@@ -145,11 +145,22 @@
     int sample_fmt;  /* sample format, currenly unused */
 
     /* the following data should not be initialized */
-    int frame_size; /* in samples, initialized when calling 'init' */
-    int frame_number; /* audio or video frame number */
-    int key_frame;    /* true if the previous compressed frame was 
-                         a key frame (intra, or seekable) */
-    int delay;        /* number of frames the decoded output will be delayed relative to the encoded input */
+    int frame_size;     /* in samples, initialized when calling 'init' */
+    int frame_number;   /* audio or video frame number */
+    int real_pict_num;  /* returns the real picture number of
+                           previous encoded frame */
+    int key_frame;      /* true if the previous compressed frame was 
+                           a key frame (intra, or seekable) */
+    int pict_type;      /* picture type of the previous 
+                           encoded frame */
+/* FIXME: these should have FF_ */
+#define I_TYPE 1 // Intra
+#define P_TYPE 2 // Predicted
+#define B_TYPE 3 // Bi-dir predicted
+#define S_TYPE 4 // S(GMC)-VOP MPEG4
+
+    int delay;          /* number of frames the decoded output 
+                           will be delayed relative to the encoded input */
     uint8_t *mbskip_table; /* =1 if MB didnt change, is only valid for I/P frames 
                               stride= mb_width = (width+15)>>4 */